// Copyright (c) FIRST and other WPILib contributors.
// Open Source Software; you can modify and/or share it under the terms of
// the WPILib BSD license file in the root directory of this project.

package frc.robot;

import com.pathplanner.lib.auto.AutoBuilder;
import com.pathplanner.lib.auto.NamedCommands;
import com.pathplanner.lib.commands.PathPlannerAuto;

import edu.wpi.first.cameraserver.CameraServer;
import edu.wpi.first.math.MathUtil;
import edu.wpi.first.wpilibj.smartdashboard.SendableChooser;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.ParallelCommandGroup;
import edu.wpi.first.wpilibj2.command.RunCommand;
import edu.wpi.first.wpilibj2.command.SequentialCommandGroup;
// Manette
import edu.wpi.first.wpilibj2.command.WaitCommand;
// Manettes
import edu.wpi.first.wpilibj2.command.button.CommandJoystick;
import edu.wpi.first.wpilibj2.command.button.CommandXboxController;
import frc.robot.command.AllumeLED;
// Commands
import frc.robot.command.Balayer;
import frc.robot.command.GrimpeurDroit;
import frc.robot.command.GrimpeurGauche;
import frc.robot.command.GuiderBas;
import frc.robot.command.GuiderHaut;
import frc.robot.command.Lancer;
import frc.robot.command.LancerNote;
import frc.robot.command.Lancerampli;
import frc.robot.command.Limelight_tracker;
import frc.robot.command.PistonFerme;
import frc.robot.command.Pistongrimpeur;
// Subsystems
import frc.robot.subsystem.Accumulateur;
import frc.robot.subsystem.Balayeuse;
import frc.robot.subsystem.Drive;
import frc.robot.subsystem.Grimpeur;
import frc.robot.subsystem.Guideur;
import frc.robot.subsystem.LED;
import frc.robot.subsystem.Lanceur;
import frc.robot.subsystem.Limelight;
import frc.robot.subsystem.Pixy;


public class RobotContainer {
  private final SendableChooser<Command> autoChooser;
  Drive drive = new Drive();
  Accumulateur accumulateur = new Accumulateur();
  Balayeuse balayeuse = new Balayeuse();
  Grimpeur grimpeur = new Grimpeur();
  Guideur guideur = new Guideur();
  Lanceur lanceur = new Lanceur();
  Limelight limelight = new Limelight();
  LED LED = new LED();
  Pixy pixy = new Pixy();
   CommandJoystick joystick = new CommandJoystick(0);
   CommandXboxController manette = new CommandXboxController(1);
   //command
   PistonFerme pistonFerme = new PistonFerme(grimpeur);
   Limelight_tracker limelight_tracker = new Limelight_tracker(limelight,drive);
   Balayer balayer = new Balayer(balayeuse, accumulateur);
  GuiderHaut guiderHaut = new GuiderHaut(guideur);
  GuiderBas guiderBas = new GuiderBas(guideur);
    Lancer lancer = new Lancer(lanceur,limelight);
  LancerNote lancernote = new LancerNote(lanceur, accumulateur);
  Lancerampli lancerampli = new Lancerampli(lanceur,limelight);
   GrimpeurDroit grimpeurDroit = new GrimpeurDroit(grimpeur, manette::getLeftX);
  GrimpeurGauche grimpeurGauche = new GrimpeurGauche(grimpeur, manette::getLeftY);
  AllumeLED allumeLED = new AllumeLED(LED);
  Pistongrimpeur pistongrimpeur = new Pistongrimpeur(grimpeur, LED);
  public RobotContainer() {
    NamedCommands.registerCommand("balayer",new Balayer(balayeuse, accumulateur));
    NamedCommands.registerCommand("lancer", new LancerNote(lanceur, accumulateur));
    NamedCommands.registerCommand("piston", new PistonFerme(grimpeur));
    autoChooser = AutoBuilder.buildAutoChooser();

    CameraServer.startAutomaticCapture();
    manette.a().whileTrue(guiderBas);
    manette.b().whileTrue(guiderHaut);
    joystick.button(3).toggleOnTrue(balayer);
    joystick.button(1).whileTrue(lancernote);
    joystick.button(4).whileTrue(new ParallelCommandGroup(lancer,limelight_tracker));
    joystick.button(2).whileTrue(new ParallelCommandGroup(lancerampli,limelight_tracker,guiderHaut));
    
    configureBindings();
     drive.setDefaultCommand(new RunCommand(()->{
     drive.drive(-MathUtil.applyDeadband(joystick.getY(),0.2), MathUtil.applyDeadband(-joystick.getX(),0.2), MathUtil.applyDeadband(-joystick.getZ(), 0.2));
    },drive));
    grimpeur.setDefaultCommand(new RunCommand(()->{
      grimpeur.droit(manette.getLeftX());}
      ,grimpeur));
      LED.setDefaultCommand(allumeLED);
      
  }

  private void configureBindings() {
  
  }

  public Command getAutonomousCommand(){
    return autoChooser.getSelected();
  }
}
